@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -76,20 +77,22 @@ class NUIKEEncryptionprofile(NURESTObject):
     
     CONST_IPSEC_AUTHENTICATION_ALGORITHM_HMAC_SHA512 = "HMAC_SHA512"
     
-    CONST_IPSEC_AUTHENTICATION_ALGORITHM_HMAC_SHA1 = "HMAC_SHA1"
+    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
-    CONST_IPSEC_SA_REPLAY_WINDOW_SIZE_WINDOW_SIZE_0 = "WINDOW_SIZE_0"
+    CONST_IPSEC_SA_REPLAY_WINDOW_SIZE_WINDOW_SIZE_1024 = "WINDOW_SIZE_1024"
     
     CONST_ISAKMP_DIFFIE_HELMAN_GROUP_IDENTIFIER_GROUP_1_768_BIT_DH = "GROUP_1_768_BIT_DH"
     
     CONST_ISAKMP_DIFFIE_HELMAN_GROUP_IDENTIFIER_GROUP_18_8192_BIT_DH = "GROUP_18_8192_BIT_DH"
     
-    CONST_IPSEC_SA_REPLAY_WINDOW_SIZE_WINDOW_SIZE_1024 = "WINDOW_SIZE_1024"
+    CONST_IPSEC_AUTHENTICATION_ALGORITHM_HMAC_SHA1 = "HMAC_SHA1"
     
     CONST_ISAKMP_AUTHENTICATION_MODE_PRE_SHARED_KEY = "PRE_SHARED_KEY"
     
     CONST_IPSEC_SA_REPLAY_WINDOW_SIZE_WINDOW_SIZE_32 = "WINDOW_SIZE_32"
     
+    CONST_IPSEC_ENCRYPTION_ALGORITHM_NULL = "NULL"
+    
     CONST_IPSEC_SA_REPLAY_WINDOW_SIZE_WINDOW_SIZE_256 = "WINDOW_SIZE_256"
     
     CONST_ISAKMP_DIFFIE_HELMAN_GROUP_IDENTIFIER_GROUP_14_2048_BIT_DH = "GROUP_14_2048_BIT_DH"
@@ -100,7 +103,7 @@ class NUIKEEncryptionprofile(NURESTObject):
     
     CONST_ISAKMP_ENCRYPTION_ALGORITHM_AES256 = "AES256"
     
-    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
+    CONST_IPSEC_AUTHENTICATION_ALGORITHM_HMAC_MD5 = "HMAC_MD5"
     
     CONST_IPSEC_ENCRYPTION_ALGORITHM_AES256 = "AES256"
     
@@ -143,6 +146,7 @@ class NUIKEEncryptionprofile(NURESTObject):
         self._ipsec_pre_fragment = None
         self._ipsec_sa_lifetime = None
         self._ipsec_sa_replay_window_size = None
+        self._ipsec_sa_replay_window_size_value = None
         self._isakmp_authentication_mode = None
         self._isakmp_diffie_helman_group_identifier = None
         self._isakmp_encryption_algorithm = None
@@ -159,13 +163,14 @@ class NUIKEEncryptionprofile(NURESTObject):
         self.expose_attribute(local_name="dpd_interval", remote_name="DPDInterval", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dpd_mode", remote_name="DPDMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'ON_DEMAND', u'REPLY_ONLY'])
         self.expose_attribute(local_name="dpd_timeout", remote_name="DPDTimeout", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="ipsec_authentication_algorithm", remote_name="IPsecAuthenticationAlgorithm", attribute_type=str, is_required=False, is_unique=False, choices=[u'HMAC_SHA1', u'HMAC_SHA256', u'HMAC_SHA512'])
+        self.expose_attribute(local_name="ipsec_authentication_algorithm", remote_name="IPsecAuthenticationAlgorithm", attribute_type=str, is_required=False, is_unique=False, choices=[u'HMAC_MD5', u'HMAC_SHA1', u'HMAC_SHA256', u'HMAC_SHA512'])
         self.expose_attribute(local_name="ipsec_dont_fragment", remote_name="IPsecDontFragment", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="ipsec_enable_pfs", remote_name="IPsecEnablePFS", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="ipsec_encryption_algorithm", remote_name="IPsecEncryptionAlgorithm", attribute_type=str, is_required=False, is_unique=False, choices=[u'AES128', u'AES192', u'AES256', u'TRIPLE_DES'])
+        self.expose_attribute(local_name="ipsec_encryption_algorithm", remote_name="IPsecEncryptionAlgorithm", attribute_type=str, is_required=False, is_unique=False, choices=[u'AES128', u'AES192', u'AES256', u'NULL', u'TRIPLE_DES'])
         self.expose_attribute(local_name="ipsec_pre_fragment", remote_name="IPsecPreFragment", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="ipsec_sa_lifetime", remote_name="IPsecSALifetime", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="ipsec_sa_replay_window_size", remote_name="IPsecSAReplayWindowSize", attribute_type=str, is_required=False, is_unique=False, choices=[u'WINDOW_SIZE_0', u'WINDOW_SIZE_1024', u'WINDOW_SIZE_128', u'WINDOW_SIZE_256', u'WINDOW_SIZE_32', u'WINDOW_SIZE_512', u'WINDOW_SIZE_64'])
+        self.expose_attribute(local_name="ipsec_sa_replay_window_size", remote_name="IPsecSAReplayWindowSize", attribute_type=str, is_required=False, is_unique=False, choices=[u'WINDOW_SIZE_1024', u'WINDOW_SIZE_128', u'WINDOW_SIZE_256', u'WINDOW_SIZE_32', u'WINDOW_SIZE_512', u'WINDOW_SIZE_64'])
+        self.expose_attribute(local_name="ipsec_sa_replay_window_size_value", remote_name="IPsecSAReplayWindowSizeValue", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="isakmp_authentication_mode", remote_name="ISAKMPAuthenticationMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'PRE_SHARED_KEY'])
         self.expose_attribute(local_name="isakmp_diffie_helman_group_identifier", remote_name="ISAKMPDiffieHelmanGroupIdentifier", attribute_type=str, is_required=False, is_unique=False, choices=[u'GROUP_14_2048_BIT_DH', u'GROUP_15_3072_BIT_DH', u'GROUP_16_4096_BIT_DH', u'GROUP_17_6144_BIT_DH', u'GROUP_18_8192_BIT_DH', u'GROUP_1_768_BIT_DH', u'GROUP_2_1024_BIT_DH', u'GROUP_5_1536_BIT_DH'])
         self.expose_attribute(local_name="isakmp_encryption_algorithm", remote_name="ISAKMPEncryptionAlgorithm", attribute_type=str, is_required=False, is_unique=False, choices=[u'AES128', u'AES192', u'AES256', u'TRIPLE_DES'])
@@ -463,6 +468,33 @@ class NUIKEEncryptionprofile(NURESTObject):
         self._ipsec_sa_replay_window_size = value
 
     
+    @property
+    def ipsec_sa_replay_window_size_value(self):
+        """ Get ipsec_sa_replay_window_size_value value.
+
+            Notes:
+                IPsec Replay Window Size in Packets.
+
+                
+                This attribute is named `IPsecSAReplayWindowSizeValue` in VSD API.
+                
+        """
+        return self._ipsec_sa_replay_window_size_value
+
+    @ipsec_sa_replay_window_size_value.setter
+    def ipsec_sa_replay_window_size_value(self, value):
+        """ Set ipsec_sa_replay_window_size_value value.
+
+            Notes:
+                IPsec Replay Window Size in Packets.
+
+                
+                This attribute is named `IPsecSAReplayWindowSizeValue` in VSD API.
+                
+        """
+        self._ipsec_sa_replay_window_size_value = value
+
+    
     @property
     def isakmp_authentication_mode(self):
         """ Get isakmp_authentication_mode value.
