@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUMetadatasFetcher
 
 
@@ -36,6 +37,9 @@ from .fetchers import NUGlobalMetadatasFetcher
 from .fetchers import NUVMsFetcher
 
 
+from .fetchers import NUContainersFetcher
+
+
 from .fetchers import NUEventLogsFetcher
 
 from bambou import NURESTObject
@@ -45,7 +49,7 @@ class NUQOS(NURESTObject):
     """ Represents a QOS in the VSD
 
         Notes:
-            The object manipulates the QoS parameters attached to a domain, zone, or subnet.
+            QoS policies enable you to classify and limit network traffic.
     """
 
     __rest_name__ = "qos"
@@ -113,6 +117,10 @@ class NUQOS(NURESTObject):
         self._service_class = None
         self._description = None
         self._rewrite_forwarding_class = None
+        self._egress_fip_committed_burst_size = None
+        self._egress_fip_committed_information_rate = None
+        self._egress_fip_peak_burst_size = None
+        self._egress_fip_peak_information_rate = None
         self._entity_scope = None
         self._committed_burst_size = None
         self._committed_information_rate = None
@@ -138,9 +146,13 @@ class NUQOS(NURESTObject):
         self.expose_attribute(local_name="rate_limiting_active", remote_name="rateLimitingActive", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="active", remote_name="active", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="peak", remote_name="peak", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="service_class", remote_name="serviceClass", attribute_type=str, is_required=True, is_unique=False, choices=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'NONE'])
+        self.expose_attribute(local_name="service_class", remote_name="serviceClass", attribute_type=str, is_required=False, is_unique=False, choices=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'NONE'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="rewrite_forwarding_class", remote_name="rewriteForwardingClass", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="egress_fip_committed_burst_size", remote_name="EgressFIPCommittedBurstSize", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="egress_fip_committed_information_rate", remote_name="EgressFIPCommittedInformationRate", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="egress_fip_peak_burst_size", remote_name="EgressFIPPeakBurstSize", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="egress_fip_peak_information_rate", remote_name="EgressFIPPeakInformationRate", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="committed_burst_size", remote_name="committedBurstSize", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="committed_information_rate", remote_name="committedInformationRate", attribute_type=str, is_required=False, is_unique=False)
@@ -164,6 +176,9 @@ class NUQOS(NURESTObject):
         self.vms = NUVMsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
+        self.containers = NUContainersFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        
+        
         self.event_logs = NUEventLogsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
 
@@ -641,6 +656,114 @@ class NUQOS(NURESTObject):
         self._rewrite_forwarding_class = value
 
     
+    @property
+    def egress_fip_committed_burst_size(self):
+        """ Get egress_fip_committed_burst_size value.
+
+            Notes:
+                Committed burst size setting in kilo-bytes (kilo-octets) for FIP Shaper on the Egress.
+
+                
+                This attribute is named `EgressFIPCommittedBurstSize` in VSD API.
+                
+        """
+        return self._egress_fip_committed_burst_size
+
+    @egress_fip_committed_burst_size.setter
+    def egress_fip_committed_burst_size(self, value):
+        """ Set egress_fip_committed_burst_size value.
+
+            Notes:
+                Committed burst size setting in kilo-bytes (kilo-octets) for FIP Shaper on the Egress.
+
+                
+                This attribute is named `EgressFIPCommittedBurstSize` in VSD API.
+                
+        """
+        self._egress_fip_committed_burst_size = value
+
+    
+    @property
+    def egress_fip_committed_information_rate(self):
+        """ Get egress_fip_committed_information_rate value.
+
+            Notes:
+                Committed information rate setting in Mb/s for FIP Shaper on the egress side.
+
+                
+                This attribute is named `EgressFIPCommittedInformationRate` in VSD API.
+                
+        """
+        return self._egress_fip_committed_information_rate
+
+    @egress_fip_committed_information_rate.setter
+    def egress_fip_committed_information_rate(self, value):
+        """ Set egress_fip_committed_information_rate value.
+
+            Notes:
+                Committed information rate setting in Mb/s for FIP Shaper on the egress side.
+
+                
+                This attribute is named `EgressFIPCommittedInformationRate` in VSD API.
+                
+        """
+        self._egress_fip_committed_information_rate = value
+
+    
+    @property
+    def egress_fip_peak_burst_size(self):
+        """ Get egress_fip_peak_burst_size value.
+
+            Notes:
+                Peak burst size setting in kilo-bytes (kilo-octets) for Egress FIP rate limiting.
+
+                
+                This attribute is named `EgressFIPPeakBurstSize` in VSD API.
+                
+        """
+        return self._egress_fip_peak_burst_size
+
+    @egress_fip_peak_burst_size.setter
+    def egress_fip_peak_burst_size(self, value):
+        """ Set egress_fip_peak_burst_size value.
+
+            Notes:
+                Peak burst size setting in kilo-bytes (kilo-octets) for Egress FIP rate limiting.
+
+                
+                This attribute is named `EgressFIPPeakBurstSize` in VSD API.
+                
+        """
+        self._egress_fip_peak_burst_size = value
+
+    
+    @property
+    def egress_fip_peak_information_rate(self):
+        """ Get egress_fip_peak_information_rate value.
+
+            Notes:
+                Peak rate setting for FIP rate limiting on egress in Mb/s
+
+                
+                This attribute is named `EgressFIPPeakInformationRate` in VSD API.
+                
+        """
+        return self._egress_fip_peak_information_rate
+
+    @egress_fip_peak_information_rate.setter
+    def egress_fip_peak_information_rate(self, value):
+        """ Set egress_fip_peak_information_rate value.
+
+            Notes:
+                Peak rate setting for FIP rate limiting on egress in Mb/s
+
+                
+                This attribute is named `EgressFIPPeakInformationRate` in VSD API.
+                
+        """
+        self._egress_fip_peak_information_rate = value
+
+    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
