@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (c) 2015, Alcatel-Lucent Inc
+# Copyright (c) 2015, Alcatel-Lucent Inc, 2017 Nokia
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -27,6 +27,7 @@
 
 
 
+
 from .fetchers import NUTCAsFetcher
 
 
@@ -66,7 +67,7 @@ class NUVMInterface(NURESTObject):
     """ Represents a VMInterface in the VSD
 
         Notes:
-            Read only API that can retrieve the VM interface associated with a domain, zone or subnet for mediation created VM's for REST created  VM interfaces you need to set the additional proxy header in http request : X-Nuage-ProxyUservalue of the header has to be either :1) enterpriseName@UserName (example :bob@Alcatel Lucent), or 2) external ID of user in VSD, typically is UUID generally decided by the CMS tool in questionUser needs to have CMS privileges to use proxy user header.
+            API that can retrieve the VM interface associated with a domain, zone or subnet for mediation created VM's for REST created  VM interfaces you need to set the additional proxy header in http request : X-Nuage-ProxyUservalue of the header has to be either :1) enterpriseName@UserName (example :bob@Alcatel Lucent), or 2) external ID of user in VSD, typically is UUID generally decided by the CMS tool in questionUser needs to have CMS privileges to use proxy user header.
     """
 
     __rest_name__ = "vminterface"
@@ -107,6 +108,8 @@ class NUVMInterface(NURESTObject):
         self._ip_address = None
         self._vport_id = None
         self._vport_name = None
+        self._ipv6_address = None
+        self._ipv6_gateway = None
         self._name = None
         self._last_updated_by = None
         self._gateway = None
@@ -119,7 +122,6 @@ class NUVMInterface(NURESTObject):
         self._domain_name = None
         self._zone_id = None
         self._zone_name = None
-        self._associated_floating_ip_address = None
         self._attached_network_id = None
         self._attached_network_type = None
         self._multi_nic_vport_name = None
@@ -130,6 +132,8 @@ class NUVMInterface(NURESTObject):
         self.expose_attribute(local_name="ip_address", remote_name="IPAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vport_id", remote_name="VPortID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vport_name", remote_name="VPortName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ipv6_address", remote_name="IPv6Address", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="ipv6_gateway", remote_name="IPv6Gateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway", remote_name="gateway", attribute_type=str, is_required=False, is_unique=False)
@@ -142,7 +146,6 @@ class NUVMInterface(NURESTObject):
         self.expose_attribute(local_name="domain_name", remote_name="domainName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="zone_id", remote_name="zoneID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="zone_name", remote_name="zoneName", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="associated_floating_ip_address", remote_name="associatedFloatingIPAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="attached_network_id", remote_name="attachedNetworkID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="attached_network_type", remote_name="attachedNetworkType", attribute_type=str, is_required=False, is_unique=False, choices=[u'L2DOMAIN', u'SUBNET'])
         self.expose_attribute(local_name="multi_nic_vport_name", remote_name="multiNICVPortName", attribute_type=str, is_required=False, is_unique=False)
@@ -324,6 +327,60 @@ class NUVMInterface(NURESTObject):
         self._vport_name = value
 
     
+    @property
+    def ipv6_address(self):
+        """ Get ipv6_address value.
+
+            Notes:
+                IPv6 address of the  interface
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        return self._ipv6_address
+
+    @ipv6_address.setter
+    def ipv6_address(self, value):
+        """ Set ipv6_address value.
+
+            Notes:
+                IPv6 address of the  interface
+
+                
+                This attribute is named `IPv6Address` in VSD API.
+                
+        """
+        self._ipv6_address = value
+
+    
+    @property
+    def ipv6_gateway(self):
+        """ Get ipv6_gateway value.
+
+            Notes:
+                IPV6 Gateway of the subnet that the VM is connected to
+
+                
+                This attribute is named `IPv6Gateway` in VSD API.
+                
+        """
+        return self._ipv6_gateway
+
+    @ipv6_gateway.setter
+    def ipv6_gateway(self, value):
+        """ Set ipv6_gateway value.
+
+            Notes:
+                IPV6 Gateway of the subnet that the VM is connected to
+
+                
+                This attribute is named `IPv6Gateway` in VSD API.
+                
+        """
+        self._ipv6_gateway = value
+
+    
     @property
     def name(self):
         """ Get name value.
@@ -636,33 +693,6 @@ class NUVMInterface(NURESTObject):
         self._zone_name = value
 
     
-    @property
-    def associated_floating_ip_address(self):
-        """ Get associated_floating_ip_address value.
-
-            Notes:
-                Floating Ip Address of this network interface eg: 10.1.2.1
-
-                
-                This attribute is named `associatedFloatingIPAddress` in VSD API.
-                
-        """
-        return self._associated_floating_ip_address
-
-    @associated_floating_ip_address.setter
-    def associated_floating_ip_address(self, value):
-        """ Set associated_floating_ip_address value.
-
-            Notes:
-                Floating Ip Address of this network interface eg: 10.1.2.1
-
-                
-                This attribute is named `associatedFloatingIPAddress` in VSD API.
-                
-        """
-        self._associated_floating_ip_address = value
-
-    
     @property
     def attached_network_id(self):
         """ Get attached_network_id value.
